@@ -2,7 +2,6 @@ package Lox::TokenType;
 use strict;
 use warnings;
 use Exporter 'import';
-our $VERSION = 0.01;
 
 my @tokens = qw(
   LEFT_PAREN RIGHT_PAREN LEFT_BRACE RIGHT_BRACE
@@ -22,9 +21,12 @@ my @tokens = qw(
   EOF
 );
 
-require enum;
-enum->import(@tokens);
+my %token_values = map { $tokens[$_] => $_ } 0..$#tokens;
+
+require constant;
+constant->import(\%token_values);
 our @EXPORT = (@tokens, 'type');
+our $VERSION = 0.02;
 
 sub type { $tokens[shift] }
 
